#!/usr/bin/env python3
"""List of XSL tags and attributes"""

__all__ = [
    "xsl_fo_tags",
    "xsl_fo_attributes",
    "xslt_tags",
    "xslt_attributes",
    "xml_attributes",
    "xsls_tags",
    "xsls_to_xslt_tags",
]
